from game import *

class Button:
    def __init__(self, pos, radius, name, tooltip):
        self.pos = pos
        self.radius = radius
        self.name = name
        self.tooltip = tooltip

    def inside(self, pos):
        x, y = self.pos
        px, py = pos
        dx, dy = x - px, y - py
        return dx ** 2 + dy ** 2 <= self.radius ** 2

    def click(self, pos):
        if self.name == "Cave":
            select_building(Cave)
        elif self.name == "Bush":
            select_building(BuilderBush)
        elif self.name == "Flower":
            select_building(PlanterBush)
        elif self.name == "Tree":
            select_building(Tree)
        elif self.name == "Defense":
            select_building(DefenseTree)
        elif self.name == "Remove":
            select_building(Remove)
        elif self.name == "Healer":
            select_building(HealerBush)

class UI:
    def __init__(self):
        self.buttons = []

        x = -0.9
        y = 1.15

        self.add_button(Button((x, y), 0.1, "Cave",
            ["Build a cave so imps can enter the lawn.",
            "Can only have one of those so place wisely."]))

        y -= 0.2

        self.add_button(Button((x, y), 0.1, "Bush",
            ["Cost: %d nectar" % BuilderBush.cost,
            "Houses a bush planter imp.",
            "Bush planter imps will plant and repair",
            "bushes and trees."]))

        y -= 0.2

        self.add_button(Button((x, y), 0.1, "Flower",
            ["Cost: %d nectar" % PlanterBush.cost,
            "Houses a garden imp.",
            "Garden imps will plant flowers."]))

        y = 1.15
        x += 0.2

        self.add_button(Button((x, y), 0.1, "Tree",
            ["Cost: %d nectar" % Tree.cost,
            "A tree houses a flower elf and provides 8 upkeep.",
            "Flower elfs collect nectar from flowers."]))

        y -= 0.2

        self.add_button(Button((x, y), 0.1, "Defense",
            ["Cost: %d nectar" % DefenseTree.cost,
            "This tree houses an elf shaman.",
            "Elf shamans can fight evil."]))

        y = 1.15
        x += 0.2

        self.add_button(Button((x, y), 0.1, "Healer",
            ["Cost: %d nectar" % Tree.cost,
            "A bush which houses a healer elf.",
            "Healer elfs can use nectar to fully heal elfs."]))

        x = -0.9
        y = -1.15
        self.add_button(Button((x, y), 0.1, "Remove",
            ["Remove a bush or tree.",
            "This may be necessary if you messed up",
            " and built more than your upkeep allows."]))

    def add_button(self, button):
        self.buttons.append(button)

    def over(self, pos):
        for b in self.buttons:
            if b.inside(pos):
                return b
        return None

    def click(self, pos):
        b = self.over(pos)
        if b:
            b.click(pos)
            return True
        return False

